@@ -188,6 +188,12 @@ static const gchar *const author_credits[] = {
   "Clytie Siddall <clytie riverland net au>",
   "Ilkka Tuohela <hile iki fi>",
   "Chao-Hsiung Liao <j_h_liau yahoo com tw>",
+  "Žygimantas Beručka <zygis gnome org>",
+  "Gabor Kelemen <kelemeng gnome hu>",
+  "Telsa Gwynne <hobbit aloss ukuu org uk>",
+  "Slobodan D. Sredojevic <ssl uns ns ac yu>",
+  "Baris Cicek <baris teamforce name tr>",
+  "Runa Bhattacharjee <runa bengalinux org>",
   NULL
 };
 
